==> gnome-shell-calculate-3.2.2.4.tar.bz2: gnome-shell-calculate-3.2.2.4/extensions/move_clock@calculate-linux.org/extension.js <==
// Copyright (C) 2012 Calculate Ltd
// Licence: GPLv2+

const Clutter = imports.gi.Clutter;
const Lang = imports.lang;
const St = imports.gi.St;
const Shell = imports.gi.Shell;
const DateMenu = imports.ui.dateMenu;
const Calendar = imports.ui.calendar;
const Gio = imports.gi.Gio;

const Main = imports.ui.main;
const Mainloop = imports.mainloop;


function _pluginUpdateClockAndDate() {
        let format = this._desktopSettings.get_string(DateMenu.CLOCK_FORMAT_KEY);
        let showDate = this._clockSettings.get_boolean(DateMenu.CLOCK_SHOW_DATE_KEY);
        let showSeconds = this._clockSettings.get_boolean(DateMenu.CLOCK_SHOW_SECONDS_KEY);
        let showWeekdata = calendarSettings.get_boolean(Calendar.SHOW_WEEKDATE_KEY);

        let clockFormat;
        let dateFormat;

        switch (format) {
            case '24h':
                if (showDate)
                    /* Translators: This is the time format with date used
                       in 24-hour mode. */
		    if(showWeekdata)
                    	clockFormat = showSeconds ? _("%a %b %e, %R:%S")
                       	                          : _("%a %b %e, %R");
		    else
                    	clockFormat = showSeconds ? _("%b %e, %R:%S")
                                                  : _("%b %e, %R");
                else
                    /* Translators: This is the time format without date used
                       in 24-hour mode. */
		    if(showWeekdata)
                    	clockFormat = showSeconds ? _("%a %R:%S")
                       	                          : _("%a %R");
		    else
                    	clockFormat = showSeconds ? _("%R:%S")
                       	                          : _("%R");
                break;
            case '12h':
            default:
                if (showDate)
                    /* Translators: This is a time format with date used
                       for AM/PM. */
                    clockFormat = showSeconds ? _("%a %b %e, %l:%M:%S %p")
                                              : _("%a %b %e, %l:%M %p");
                else
                    /* Translators: This is a time format without date used
                       for AM/PM. */
                    clockFormat = showSeconds ? _("%a %l:%M:%S %p")
                                              : _("%a %l:%M %p");
                break;
        }

        let displayDate = new Date();

        this._clock.set_text(displayDate.toLocaleFormat(clockFormat));

        /* Translators: This is the date format to use when the calendar popup is
         * shown - it is shown just below the time in the shell (e.g. "Tue 9:29 AM").
         */
        dateFormat = _("%A %B %e, %Y");
        this._date.set_text(displayDate.toLocaleFormat(dateFormat));

        Mainloop.timeout_add_seconds(1, Lang.bind(this, this._updateClockAndDate));
        return false;
}

let oldFunc, dateMenu, label, box;

function init() {
    dateMenu = Main.panel._dateMenu;
    label = dateMenu._clock;
    label.add_style_class_name('clock-label');
    oldFunc = Main.panel._dateMenu._updateClockAndDate;
    calendarSettings = new Gio.Settings({ schema: 'org.gnome.shell.calendar' });
}

function enable() {
    Main.panel._dateMenu._updateClockAndDate = _pluginUpdateClockAndDate;
}

function disable() {
    Main.panel._dateMenu._updateClockAndDate = oldFunc;
}

==> gnome-shell-calculate-3.2.2.15.tar.bz2: gnome-shell-calculate-3.2.2.15/extensions/move_clock@calculate-linux.org/extension.js <==
// Copyright (C) 2012 Calculate Ltd
// Licence: GPLv2+

const Clutter = imports.gi.Clutter;
const Lang = imports.lang;
const St = imports.gi.St;
const Shell = imports.gi.Shell;
const DateMenu = imports.ui.dateMenu;
const Calendar = imports.ui.calendar;
const Gio = imports.gi.Gio;

const Main = imports.ui.main;
const Mainloop = imports.mainloop;

let oldFunc, dateMenu, label, box, calendarSettings;

function _pluginUpdateClockAndDate() {
        let format = this._desktopSettings.get_string(DateMenu.CLOCK_FORMAT_KEY);
        let showDate = this._clockSettings.get_boolean(DateMenu.CLOCK_SHOW_DATE_KEY);
        let showSeconds = this._clockSettings.get_boolean(DateMenu.CLOCK_SHOW_SECONDS_KEY);
        let showWeekdata = calendarSettings.get_boolean(Calendar.SHOW_WEEKDATE_KEY);

        let clockFormat;
        let dateFormat;

        switch (format) {
            case '24h':
                if (showDate)
                    /* Translators: This is the time format with date used
                       in 24-hour mode. */
		    if(showWeekdata)
                    	clockFormat = showSeconds ? _("%a %b %e, %R:%S")
                       	                          : _("%a %b %e, %R");
		    else
                    	clockFormat = showSeconds ? _("%b %e, %R:%S")
                                                  : _("%b %e, %R");
                else
                    /* Translators: This is the time format without date used
                       in 24-hour mode. */
		    if(showWeekdata)
                    	clockFormat = showSeconds ? _("%a %R:%S")
                       	                          : _("%a %R");
		    else
                    	clockFormat = showSeconds ? _("%R:%S")
                       	                          : _("%R");
                break;
            case '12h':
            default:
                if (showDate)
                    /* Translators: This is a time format with date used
                       for AM/PM. */
                    clockFormat = showSeconds ? _("%a %b %e, %l:%M:%S %p")
                                              : _("%a %b %e, %l:%M %p");
                else
                    /* Translators: This is a time format without date used
                       for AM/PM. */
                    clockFormat = showSeconds ? _("%a %l:%M:%S %p")
                                              : _("%a %l:%M %p");
                break;
        }

        let displayDate = new Date();

        this._clock.set_text(displayDate.toLocaleFormat(clockFormat));

        /* Translators: This is the date format to use when the calendar popup is
         * shown - it is shown just below the time in the shell (e.g. "Tue 9:29 AM").
         */
        dateFormat = _("%A %B %e, %Y");
        this._date.set_text(displayDate.toLocaleFormat(dateFormat));

        Mainloop.timeout_add_seconds(1, Lang.bind(this, this._updateClockAndDate));
        return false;
}

function init() {
    dateMenu = Main.panel._dateMenu;
    label = dateMenu._clock;
    label.add_style_class_name('clock-label');
    oldFunc = Main.panel._dateMenu._updateClockAndDate;
    calendarSettings = new Gio.Settings({ schema: 'org.gnome.shell.calendar' });
}

function enable() {
    Main.panel._dateMenu._updateClockAndDate = _pluginUpdateClockAndDate;
}

function disable() {
    Main.panel._dateMenu._updateClockAndDate = oldFunc;
}
